@@ -393,12 +393,10 @@ def compute_alpha_signal_ls(lo_df=None, core_tokens=['BTC', 'ETH'], extra_tokens
     return merged_df.copy()
 
 def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_tokens=['AVAX'], moderating_factor = 0.1, frequency='weekly', generate_kpis = True, plot_html=True, stop_loss_quantile = 0.75,take_profit_quantile = 0.75,write_excel_file = True, local_root_directory = None, plot_metrics = True,plot_html_save = True):
-
-    merged_df = data_df.copy()
     ssjs = core_tokens + extra_tokens
     if plot_html:
         title = 'HedgeFarm Strategy'
-        backtest_df = merged_df[['COMBO_STRAT']].copy()
+        backtest_df = data_df[['COMBO_STRAT']].copy()
         backtest_df.columns = ['strategy']
         fig = realtime_plotting_utility.plot_multiple_time_series(
             data_df=backtest_df,
@@ -414,7 +412,7 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
                                                              local_root_directory, plot_html=True,
                                                              write_file=True)
         btd_kpis, ytd_kpis, past_returns = riskmetrics.compute_extensive_kpis(
-            data_df=merged_df.copy(), strat='COMBO_STRAT')
+            data_df=data_df.copy(), strat='COMBO_STRAT')
 
         go_comp_kpi = lambda x: compute_metrics(x, strat=me_strat)
 
@@ -427,10 +425,10 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
 
 
         comp_alloc = lambda x: compute_allocation(x, universe=ssjs)
-        merged_df['COMBO_STRAT_compo'] = merged_df.apply(comp_alloc, axis=1)
+        data_df['COMBO_STRAT_compo'] = data_df.apply(comp_alloc, axis=1)
 
         ############# strategy drawdown
-        dd_data_df = merged_df.copy() #pd.merge(merged_df.copy(), sol_ohlc_df.copy(), left_index=True,
+        dd_data_df = data_df.copy() #pd.merge(merged_df.copy(), sol_ohlc_df.copy(), left_index=True,
                               #right_index=True)
         limited_dd_data_df = dd_data_df[dd_data_df.index >= '2021-04-01'].copy()
         limited_dd_data_df = limited_dd_data_df[limited_dd_data_df.index <= '2021-07-01'].copy()
@@ -466,7 +464,7 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
                                                                     list(new_names.values()))
             fig.show()
 
-            dollar_df = merged_df[['DOLLAR_COMBO_STRAT']].copy()
+            dollar_df = data_df[['DOLLAR_COMBO_STRAT']].copy()
             new_names = {'DOLLAR_COMBO_STRAT': 'Absolute Return DeFi Strategy'}
             dollar_df = dollar_df.rename(columns=new_names)
             fig = realtime_plotting_utility.plot_dollar_multiple_time_series(data_df=dollar_df,
@@ -476,7 +474,7 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
             fig.show()
 
             fig = realtime_plotting_utility.plot_multiple_time_series(
-                data_df=merged_df[['long_expo', 'short_expo']],
+                data_df=data_df[['long_expo', 'short_expo']],
                 logy=False, split=False,
                 put_on_same_scale=False,
                 title=f'long/short exposition (exposition moderating factor {moderating_factor}  rebalancing {frequency})')
@@ -485,13 +483,13 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
         print('computing KPIs per epoch')
 
         me_strat = 'COMBO_STRAT'
-        whole_period_kpi_df = riskmetrics.get_kpi(merged_df[[me_strat]])
+        whole_period_kpi_df = riskmetrics.get_kpi(data_df[[me_strat]])
         whole_period_kpi_df = whole_period_kpi_df.iloc[1:]
 
-        kpi_df = riskmetrics.get_kpi(merged_df[[me_strat]])
+        kpi_df = riskmetrics.get_kpi(data_df[[me_strat]])
         stub = f'mf_{moderating_factor}_strat_{me_strat}'
         kpi_df.columns = [stub]
-        to_store_df = merged_df.copy()
+        to_store_df = data_df.copy()
         to_store_df['Date'] = to_store_df.index
 
         #### new fresh weights on monday
@@ -688,6 +686,7 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
             past_returns.to_excel(writer, sheet_name='common')
             writer.save()
 
-    btd_kpis, ytd_kpis, past_returns = riskmetrics.compute_extensive_kpis(data_df=merged_df.copy(),strat='COMBO_STRAT')
+    btd_kpis, ytd_kpis, past_returns = riskmetrics.compute_extensive_kpis(data_df=data_df.copy(),strat='COMBO_STRAT')
+    return payload_message
 
 
