@@ -790,6 +790,10 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 'calmar': 'epoch realized calmar ratio',
                 'mdd': 'epoch realized max drawdown'})
 
+            epochkpis_df['epoch realized return'] = epochkpis_df['epoch realized return']*100.
+            epochkpis_df['epoch realized annualized volatility'] = epochkpis_df['epoch realized annualized volatility']*100.
+            epochkpis_df['epoch realized max drawdown'] = epochkpis_df['epoch realized max drawdown']*100.
+
             epochkpis_df['epoch realized return'] = epochkpis_df['epoch realized return'].round(
                 decimals=2)
             epochkpis_df['epoch realized annualized return'] = epochkpis_df[
@@ -846,13 +850,13 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 to_plot_df = to_plot_df[
                     ['epoch realized return', 'epoch realized max drawdown']].copy()
                 fig = realtime_plotting_utility.plot_multiple_bar_series(
-                    data_df=to_plot_df[['epoch realized return']] * 100.,
+                    data_df=to_plot_df[['epoch realized return']],
                     logy=False, split=False,
                     put_on_same_scale=False,
                     title=f'epoch realized return in percent')
                 fig.show()
                 fig = realtime_plotting_utility.plot_multiple_bar_series(
-                    data_df=to_plot_df[['epoch realized max drawdown']] * 100.,
+                    data_df=to_plot_df[['epoch realized max drawdown']],
                     logy=False, split=False,
                     put_on_same_scale=False,
                     title=f'epoch realized max drawdown in percent')
